@@ -11,16 +11,17 @@
 ## along with this program; if not, write to the Free Software
 ## Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-from mako.template import Template
+import cgi
 import re
 import sys
 import optparse
+from .style import template as style_template
 
-from tw2.core.dottedtemplatelookup import DottedTemplateLookup
-lookup = DottedTemplateLookup(input_encoding='utf-8',
-                              output_encoding='utf-8',
-                              imports=[],
-                              default_filters=[])
+_template = (
+    u'<html>\n<head><style type="text/css">{style}</style>\n</head>\n' +
+    u'<body class="body_foreground body_background" ' +
+    u'style="font-size: {font_size};" >\n' +
+    u'<pre>\n{content}\n</pre>\n</body>\n\n</html>\n')
 
 
 class Ansi2HTMLConverter(object):
@@ -39,7 +40,7 @@ class Ansi2HTMLConverter(object):
         self.font_size = font_size
         self._attrs = None
 
-        self.ansi_codes_prog = re.compile( '\033\\[' '([\\d;]*)' '([a-zA-z])')
+        self.ansi_codes_prog = re.compile('\033\\[' '([\\d;]*)' '([a-zA-z])')
 
     def apply_regex(self, ansi):
         parts = self._apply_regex(ansi)
@@ -48,9 +49,9 @@ class Ansi2HTMLConverter(object):
 
     def _apply_regex(self, ansi):
         specials = {
-            '&' : '&amp;',
-            '<' : '&lt;',
-            '>' : '&gt;',
+            '&': '&amp;',
+            '<': '&lt;',
+            '>': '&gt;',
         }
         patterns = ['&', '<', '>']
         for pattern in patterns:
@@ -84,16 +85,15 @@ class Ansi2HTMLConverter(object):
 
         yield ansi[last_end:]
 
-
     def prepare(self, ansi=''):
         """ Load the contents of 'ansi' into this object """
 
         body = self.apply_regex(ansi)
 
         self._attrs = {
-            'dark_bg' : self.dark_bg,
-            'font_size' : self.font_size,
-            'body' : body.decode('utf-8')
+            'dark_bg': self.dark_bg,
+            'font_size': self.font_size,
+            'body': body.decode('utf-8')
         }
 
         return self._attrs
@@ -101,26 +101,26 @@ class Ansi2HTMLConverter(object):
     def attrs(self):
         """ Prepare attributes for the template """
         if not self._attrs:
-            raise Exception, "Method .prepare not yet called."
+            raise Exception("Method .prepare not yet called.")
         return self._attrs
 
-    def template(self, full):
-        """ Load the template """
-        tmpl = 'ansi2html.templates.full'
-        if not full:
-            tmpl = 'ansi2html.templates.fragment'
-        return lookup.get_template(tmpl)
-
     def convert(self, ansi, full=True):
-        return self.template(full).render_unicode(**self.prepare(ansi))
+        attrs = self.prepare(ansi)
+        if not full:
+            return attrs["body"]
+        else:
+            return _template.format(
+                style=cgi.escape(style_template(self.dark_bg)),
+                font_size=self.font_size,
+                content=attrs["body"]
+            )
 
     def produce_headers(self):
-        return lookup.get_template(
-            'ansi2html.templates.header'
-        ).render_unicode(
-            **self.prepare()
+        return '<style type="text/css">{style}</style>\n'.format(
+            style=cgi.escape(style_template(self.dark_bg))
         )
 
+
 def main():
     """
     $ ls --color=always | ansi2html > directories.html
@@ -129,9 +129,30 @@ def main():
     """
 
     parser = optparse.OptionParser(usage=main.__doc__)
-    parser.parse_args()
+    parser.add_option(
+        "-p", "--partial", dest="partial",
+        default=False, action="store_true",
+        help="Process lines as them come in.  No headers are produced.")
+    parser.add_option(
+        "-H", "--headers", dest="headers",
+        default=False, action="store_true",
+        help="Just produce the <style> tag.")
+    opts, args = parser.parse_args()
 
     conv = Ansi2HTMLConverter()
-    ansi = " ".join(sys.stdin.readlines())
-    html = conv.convert(ansi)
-    print html
+
+    # Produce only the headers and quit
+    if opts.headers:
+        print conv.produce_headers()
+        return
+
+    # Process input line-by-line.  Produce no headers.
+    if opts.partial:
+        # FIXME:  I don't know how to stop!
+        while True:
+            line = sys.stdin.readline()
+            print conv.convert(ansi=line, full=False)[:-1],  # Strip newlines
+        return
+
+    # Otherwise, just process the whole thing in one go
+    print conv.convert(" ".join(sys.stdin.readlines()))
